/****************************************************************************
** Meta object code from reading C++ file 'Polkit1Backend.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../kauth-6.25.0/src/backends/polkit-1/Polkit1Backend.h"
#include <QtCore/qmetatype.h>
#include <QtCore/qplugin.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'Polkit1Backend.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN5KAuth14Polkit1BackendE_t {};
} // unnamed namespace

template <> constexpr inline auto KAuth::Polkit1Backend::qt_create_metaobjectdata<qt_meta_tag_ZN5KAuth14Polkit1BackendE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KAuth::Polkit1Backend",
        "checkForResultChanged",
        ""
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'checkForResultChanged'
        QtMocHelpers::SlotData<void()>(1, 2, QMC::AccessPrivate, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<Polkit1Backend, qt_meta_tag_ZN5KAuth14Polkit1BackendE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject KAuth::Polkit1Backend::staticMetaObject = { {
    QMetaObject::SuperData::link<AuthBackend::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN5KAuth14Polkit1BackendE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN5KAuth14Polkit1BackendE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN5KAuth14Polkit1BackendE_t>.metaTypes,
    nullptr
} };

void KAuth::Polkit1Backend::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<Polkit1Backend *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->checkForResultChanged(); break;
        default: ;
        }
    }
    (void)_a;
}

const QMetaObject *KAuth::Polkit1Backend::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KAuth::Polkit1Backend::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN5KAuth14Polkit1BackendE_t>.strings))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "org.kde.kf6auth.AuthBackend/0.1"))
        return static_cast< KAuth::AuthBackend*>(this);
    return AuthBackend::qt_metacast(_clname);
}

int KAuth::Polkit1Backend::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = AuthBackend::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 1)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 1)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 1;
    }
    return _id;
}
using namespace KAuth;

#ifdef QT_MOC_EXPORT_PLUGIN_V2
static constexpr unsigned char qt_pluginMetaDataV2_Polkit1Backend[] = {
    0xbf, 
    // "IID"
    0x02,  0x76,  'o',  'r',  'g',  '.',  'k',  'd', 
    'e',  '.',  'P',  'o',  'l',  'k',  'i',  't', 
    '1',  'B',  'a',  'c',  'k',  'e',  'n',  'd', 
    // "className"
    0x03,  0x6e,  'P',  'o',  'l',  'k',  'i',  't', 
    '1',  'B',  'a',  'c',  'k',  'e',  'n',  'd', 
    0xff, 
};
QT_MOC_EXPORT_PLUGIN_V2(KAuth::Polkit1Backend, Polkit1Backend, qt_pluginMetaDataV2_Polkit1Backend)
#else
QT_PLUGIN_METADATA_SECTION
Q_CONSTINIT static constexpr unsigned char qt_pluginMetaData_Polkit1Backend[] = {
    'Q', 'T', 'M', 'E', 'T', 'A', 'D', 'A', 'T', 'A', ' ', '!',
    // metadata version, Qt version, architectural requirements
    0, QT_VERSION_MAJOR, QT_VERSION_MINOR, qPluginArchRequirements(),
    0xbf, 
    // "IID"
    0x02,  0x76,  'o',  'r',  'g',  '.',  'k',  'd', 
    'e',  '.',  'P',  'o',  'l',  'k',  'i',  't', 
    '1',  'B',  'a',  'c',  'k',  'e',  'n',  'd', 
    // "className"
    0x03,  0x6e,  'P',  'o',  'l',  'k',  'i',  't', 
    '1',  'B',  'a',  'c',  'k',  'e',  'n',  'd', 
    0xff, 
};
QT_MOC_EXPORT_PLUGIN(KAuth::Polkit1Backend, Polkit1Backend)
#endif  // QT_MOC_EXPORT_PLUGIN_V2

QT_WARNING_POP
